Other ``string`` functions
--------------------------

This chapter does not cover all the ``string`` functions. Two additional
ones, ``c_str`` and ``substr``, are covered in
:numref:`finput` and :numref:`parsing`.
